@@ -5,7 +5,7 @@
   accept.method <- c("TIC", "median", "PQN")
   if (!any(method %in% accept.method))
   {
-    stop("Valid methods are: ", paste0(accept.method, collapse = ", "), ".")
+    stop(".normIntensity: Valid methods are: ", paste0(accept.method, collapse = ", "), ".")
   }
   x[x == 0] <- NA
   x <- switch(method,
@@ -34,13 +34,15 @@
                 }
                 x[x == 0] <- NA
 
-                ## Try to use the faster method, if memory is not enough then
+                ## Try to use the faster method, if there is not enough RAM, then
                 ## use the slower method
 
                 ## Reference spectrum = non-zero median peaks
                 ref.spectrum <- tryCatch(apply(x, 2, median, na.rm = T),
-                                         error = function(e) {
-                                           warning("Low memory. Using the slower method to calculate the reference spectrum.")
+                                         error = function(e)
+                                         {
+                                           warning("Low memory. Using the slower
+                                                   method to calculate the reference spectrum.")
                                            z <- array(NA, ncol(x))
                                            for (j in 1:ncol(x))
                                            {
@@ -50,8 +52,10 @@
                                          })
                 ## Quotients
                 quotients <- tryCatch(x / rep(ref.spectrum, each = nrow(x)),
-                                      error = function(e) {
-                                        warning("Low memory. Using the slower method to calculate the quotients.")
+                                      error = function(e)
+                                      {
+                                        warning("Low memory. Using the slower
+                                                method to calculate the quotients.")
                                         z <- matrix(NA, nrow(x), ncol(x))
                                         for (j in 1:nrow(x))
                                         {
@@ -62,8 +66,10 @@
                 quotients[quotients == 0] <- NA
                 ## Scaling factors
                 sc.factor <- tryCatch(apply(quotients, 1, median, na.rm = T),
-                                      error = function(e) {
-                                        warning("Low memory. Using the slower method to calculate the scaling factors.")
+                                      error = function(e)
+                                      {
+                                        warning("Low memory. Using the slower
+                                                method to calculate the scaling factors.")
                                         z <- array(NA, nrow(quotients))
                                         for (j in 1:nrow(quotients))
                                         {
@@ -77,24 +83,48 @@
                   sc.factor.mat <- sapply(sc.factor, function(z) rep(z, ncol(x)))
                   x / t(sc.factor.mat)
                 },
-                error = function(e) {
-                  warning("Low memory. Using the slower method to calculate the normalized intensities.")
+                error = function(e)
+                {
+                  warning("Low memory. Using the slower method to calculate the
+                          normalized intensities.")
                   for (j in 1:nrow(x))
                   {
                     x[j, ] <- x[j, ] / sc.factor[j]
                   }
                   return(x)
                 })
+                
                 x[is.na(x)] <- 0
+                
                 x
-              })
+              }
+  )
+  
   x[is.na(x)] <- 0
-  x
+  
+  return(x)
 }
 
-## .varTransf
+## Reduce heteroscedasticity
 .varTransf <- function(x, method = "log")
 {
+  ## Check if NAs are present
+  if (any(is.na(x)))
+  {
+    stop("NAs values found in the matrix.")
+  }
+  ## Check if negative values are present
+  if (min(x) < 0)
+  {
+    stop("found negative values in the matrix.")
+  }
+  ## If the smallest intensity is not zero, show a warning saying that the intensities
+  ## will still summed to 1
+  if (min(x) > 0)
+  {
+    warning("the smallest value is larger than 0.")
+  }
+  
   accept.method <- c("log", "log2", "log10", "sqrt")
   if (!any(method %in% accept.method))
   {
